#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-9xcuIyUA39d88tYJi2GWVt
key:                  what4-1.6-9xcuIyUA39d88tYJi2GWVt
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  2e5e101c6dcd11825ddced255cbc8a6e
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-9xcuIyUA39d88tYJi2GWVt
depends:
    BoundedChan-1.0.3.0-KC4GwTTdtFBGyIaMAN8c52
    async-2.2.6-L49doqolqOiLsPy3OvdI1h
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    bifunctors-5.6.3-FTVXhqzScTfLrb1caTdfv2
    bimap-0.5.0-9LGePV6b2rwL0YEmmtUIi7
    bv-sized-1.0.6-Fwbnm2LfeIkDbtiyGJTLNY bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-AGE3z4eVx6K4O3l1mTNQex
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    deepseq-1.4.8.1 deriving-compat-0.6.8-1UyVPij6n2JGYo4roVxD36
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    fingertree-0.1.6.3-JZAMG7XazpN87D7oYiZFy7 ghc-prim-0.10.0
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    hashtables-1.4.2-1a5rFt3DzCO7jqr2tjpvji
    io-streams-1.5.2.2-HUCElSXCJdwErApRr6tdrM
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    libBF-0.6.7-6CSFbjLOatS58ha3rO8LFE
    megaparsec-9.7.0-IhFYCfUpu092G9CaEkXpKA mtl-2.3.1
    ordered-containers-0.2.4-2GzTVkJIkTsLq3516cli7m
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.11.0-CKegJzNphBnDTybUPONqXi parsec-3.1.16.1
    prettyprinter-1.7.1-3tqZuvkzaQgKArc0IOnBsn process-1.6.19.0
    s-cargot-0.1.6.0-2xWQg8ApJSIKbNNFupHrU7
    scientific-0.3.8.1-25vWQKW70jDDFFn5H243Ra stm-2.5.1.0
    template-haskell-2.20.0.0 temporary-1.3-A3KjuMYmCbV2j39Y1k6FK6
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-lift-instances-0.1.20-AXUxglL4M8CDRPIbfYe5LR time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-Jl71xZxtWw8GvgwO5TEzPz
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4
    versions-6.0.8-WekfbZNfOu9kJ07kkG0AA
    zenc-0.1.2-3R6k50Tk6NMZVGZqtliSq

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

